==> mingw-w64-clang-aarch64-flecs-docs-3.2.6-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/search/functions_2.js <==
var searchData=
[
  ['c_5fptr_0',['c_ptr',['../structflecs_1_1world.html#a4a4f6b0f12aee0ab50e31725d3db4870',1,'flecs::world']]],
  ['changed_1',['changed',['../structflecs_1_1iter.html#a6f5be52fa84313a45013a69684d3d36b',1,'flecs::iter::changed()'],['../structflecs_1_1query__base.html#a0ad5a8a2e4b98d4b59ae4dd9be36486a',1,'flecs::query_base::changed()']]],
  ['child_5fof_2',['child_of',['../structflecs_1_1entity__builder.html#a0efd25d61e1a4120bca90aec52ab7451',1,'flecs::entity_builder::child_of(entity_t second)'],['../structflecs_1_1entity__builder.html#a195830f35d74b13e7f0cca5f046de9d9',1,'flecs::entity_builder::child_of()']]],
  ['children_3',['children',['../structflecs_1_1entity__view.html#aef427d1dbbd9284cbc59a05ed94011db',1,'flecs::entity_view::children(flecs::entity_t rel, Func &amp;&amp;func) const'],['../structflecs_1_1entity__view.html#a659680859e43371687f880b0781b6ef9',1,'flecs::entity_view::children(Func &amp;&amp;func) const'],['../structflecs_1_1entity__view.html#abedd0dd7e0b9dae8e9cc25d717ee4e3e',1,'flecs::entity_view::children(Func &amp;&amp;func) const'],['../structflecs_1_1world.html#a9096b814988d64289b2805aa2717fa72',1,'flecs::world::children()']]],
  ['clear_4',['clear',['../structflecs_1_1entity.html#a3a115a6cbd08c6de08e0ecfe8608ccbb',1,'flecs::entity::clear()'],['../structflecs_1_1opaque.html#a5f30eb4fa4a9c480d28694ccea0fd62c',1,'flecs::opaque::clear()']]],
  ['column_5',['column',['../structflecs_1_1column.html#a51c9ab4d61d59f92f3267a5be8ac80fa',1,'flecs::column::column(T *array, size_t count, bool is_shared=false)'],['../structflecs_1_1column.html#aef26490bcfcca172e5992ce8e3edf399',1,'flecs::column::column(iter &amp;iter, int column)']]],
  ['column_5findex_6',['column_index',['../structflecs_1_1iter.html#ac114cb8cf4b2561b163d5684667a1c7b',1,'flecs::iter::column_index()'],['../structflecs_1_1table.html#a3d2a9da3c934c6a6b0ceb41b77f87dd0',1,'flecs::table::column_index(flecs::id_t id) const'],['../structflecs_1_1table.html#ab924cc62a25767642701f82e72aedde6',1,'flecs::table::column_index() const'],['../structflecs_1_1table.html#ac30c5eaa596849a87323c0f607dd1056',1,'flecs::table::column_index(flecs::entity_t first, flecs::entity_t second) const'],['../structflecs_1_1table.html#aa6b351010d0d6741f029186d53ccb6d0',1,'flecs::table::column_index(flecs::entity_t second) const'],['../structflecs_1_1table.html#a9655448c49fe03f6b6523c78dc8e4080',1,'flecs::table::column_index() const']]],
  ['column_5fsize_7',['column_size',['../structflecs_1_1table.html#ae7a54c5abb506d37cd2829f72d6053a2',1,'flecs::table']]],
  ['component_8',['component',['../structflecs_1_1component.html#a354267ca96c1c6ab7c75b42633e1541d',1,'flecs::component::component()'],['../group__cpp__components.html#ga07c63e1c392b8c8379c3573d1417787b',1,'flecs::world::component(Args &amp;&amp;... args) const'],['../group__cpp__components.html#gafec4b378333f9542567f194a7d7e010a',1,'flecs::world::component(Args &amp;&amp;... args) const']]],
  ['constant_9',['constant',['../group__cpp__addons__meta.html#ga232842b5b739911a9124334f8e70981c',1,'flecs::component']]],
  ['count_10',['count',['../structflecs_1_1opaque.html#add6d4f9c3e23fe3a410d620846585ea3',1,'flecs::opaque::count()'],['../structflecs_1_1table.html#a5fb29e445a1bb0ea414e2ec83b2baf69',1,'flecs::table::count()'],['../group__cpp__types.html#ga516c4b14c449bfcfdefecddad427e5be',1,'flecs::type::count()'],['../structflecs_1_1iterable.html#a69921d5fb6492c403ee2e1acd6c82a64',1,'flecs::iterable::count()'],['../structflecs_1_1world.html#af21d1a18b99f12fc99db1eb640f82ed2',1,'flecs::world::count(flecs::id_t component_id) const'],['../structflecs_1_1world.html#a86f17bc426832a0e5687db9f200501d3',1,'flecs::world::count(flecs::entity_t first, flecs::entity_t second) const'],['../structflecs_1_1world.html#a3850e139db8dba1cc3826e5d6bc4eb5f',1,'flecs::world::count() const'],['../structflecs_1_1world.html#ab328881b80dc6be0ee1ced10ff91ad8d',1,'flecs::world::count(flecs::entity_t second) const'],['../structflecs_1_1world.html#a7e470cd6545b0e306010d02446d5f24e',1,'flecs::world::count() const']]],
  ['ctx_11',['ctx',['../structflecs_1_1iter.html#a8af7d2bbeea498897524acb9a2227145',1,'flecs::iter::ctx()'],['../structflecs_1_1iter.html#a7ce67fa9264646552086f8609f60bcc2',1,'flecs::iter::ctx()'],['../structflecs_1_1observer__builder__i.html#a75a45fd36b7658b358b087214256054e',1,'flecs::observer_builder_i::ctx()'],['../structflecs_1_1system__builder__i.html#a4dea589a99a1e97a4998332c6becfb76',1,'flecs::system_builder_i::ctx()']]],
  ['cursor_12',['cursor',['../group__cpp__addons__meta.html#ga7801bddc835d400dc71c6261f64fba2b',1,'flecs::world::cursor(flecs::entity_t tid, void *ptr)'],['../group__cpp__addons__meta.html#gaf14e2f21de0df9ac42c914b5bf942b8b',1,'flecs::world::cursor(void *ptr)']]]
];

==> mingw-w64-clang-aarch64-flecs-docs-3.2.7-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/search/functions_2.js <==
var searchData=
[
  ['c_5fptr_0',['c_ptr',['../structflecs_1_1world.html#a4a4f6b0f12aee0ab50e31725d3db4870',1,'flecs::world']]],
  ['changed_1',['changed',['../structflecs_1_1query__base.html#a0ad5a8a2e4b98d4b59ae4dd9be36486a',1,'flecs::query_base']]],
  ['child_5fof_2',['child_of',['../structflecs_1_1entity__builder.html#a0efd25d61e1a4120bca90aec52ab7451',1,'flecs::entity_builder::child_of(entity_t second)'],['../structflecs_1_1entity__builder.html#a195830f35d74b13e7f0cca5f046de9d9',1,'flecs::entity_builder::child_of()']]],
  ['children_3',['children',['../structflecs_1_1entity__view.html#aef427d1dbbd9284cbc59a05ed94011db',1,'flecs::entity_view::children(flecs::entity_t rel, Func &amp;&amp;func) const'],['../structflecs_1_1entity__view.html#a659680859e43371687f880b0781b6ef9',1,'flecs::entity_view::children(Func &amp;&amp;func) const'],['../structflecs_1_1entity__view.html#abedd0dd7e0b9dae8e9cc25d717ee4e3e',1,'flecs::entity_view::children(Func &amp;&amp;func) const'],['../structflecs_1_1world.html#a9096b814988d64289b2805aa2717fa72',1,'flecs::world::children()']]],
  ['clear_4',['clear',['../structflecs_1_1entity.html#a3a115a6cbd08c6de08e0ecfe8608ccbb',1,'flecs::entity::clear()'],['../structflecs_1_1opaque.html#a5f30eb4fa4a9c480d28694ccea0fd62c',1,'flecs::opaque::clear()']]],
  ['column_5',['column',['../structflecs_1_1column.html#a51c9ab4d61d59f92f3267a5be8ac80fa',1,'flecs::column::column(T *array, size_t count, bool is_shared=false)'],['../structflecs_1_1column.html#aef26490bcfcca172e5992ce8e3edf399',1,'flecs::column::column(iter &amp;iter, int column)']]],
  ['column_5findex_6',['column_index',['../structflecs_1_1table.html#a3d2a9da3c934c6a6b0ceb41b77f87dd0',1,'flecs::table::column_index(flecs::id_t id) const'],['../structflecs_1_1table.html#ab924cc62a25767642701f82e72aedde6',1,'flecs::table::column_index() const'],['../structflecs_1_1table.html#ac30c5eaa596849a87323c0f607dd1056',1,'flecs::table::column_index(flecs::entity_t first, flecs::entity_t second) const'],['../structflecs_1_1table.html#aa6b351010d0d6741f029186d53ccb6d0',1,'flecs::table::column_index(flecs::entity_t second) const'],['../structflecs_1_1table.html#a9655448c49fe03f6b6523c78dc8e4080',1,'flecs::table::column_index() const']]],
  ['column_5fsize_7',['column_size',['../structflecs_1_1table.html#ae7a54c5abb506d37cd2829f72d6053a2',1,'flecs::table']]],
  ['component_8',['component',['../structflecs_1_1component.html#a354267ca96c1c6ab7c75b42633e1541d',1,'flecs::component::component()'],['../group__cpp__components.html#ga07c63e1c392b8c8379c3573d1417787b',1,'flecs::world::component(Args &amp;&amp;... args) const'],['../group__cpp__components.html#gafec4b378333f9542567f194a7d7e010a',1,'flecs::world::component(Args &amp;&amp;... args) const']]],
  ['constant_9',['constant',['../group__cpp__addons__meta.html#ga232842b5b739911a9124334f8e70981c',1,'flecs::component']]],
  ['count_10',['count',['../structflecs_1_1opaque.html#add6d4f9c3e23fe3a410d620846585ea3',1,'flecs::opaque::count()'],['../structflecs_1_1table.html#a5fb29e445a1bb0ea414e2ec83b2baf69',1,'flecs::table::count()'],['../group__cpp__types.html#ga516c4b14c449bfcfdefecddad427e5be',1,'flecs::type::count()'],['../structflecs_1_1iterable.html#a69921d5fb6492c403ee2e1acd6c82a64',1,'flecs::iterable::count()'],['../structflecs_1_1world.html#af21d1a18b99f12fc99db1eb640f82ed2',1,'flecs::world::count(flecs::id_t component_id) const'],['../structflecs_1_1world.html#a86f17bc426832a0e5687db9f200501d3',1,'flecs::world::count(flecs::entity_t first, flecs::entity_t second) const'],['../structflecs_1_1world.html#a3850e139db8dba1cc3826e5d6bc4eb5f',1,'flecs::world::count() const'],['../structflecs_1_1world.html#ab328881b80dc6be0ee1ced10ff91ad8d',1,'flecs::world::count(flecs::entity_t second) const'],['../structflecs_1_1world.html#a7e470cd6545b0e306010d02446d5f24e',1,'flecs::world::count() const']]],
  ['ctx_11',['ctx',['../structflecs_1_1observer__builder__i.html#a75a45fd36b7658b358b087214256054e',1,'flecs::observer_builder_i::ctx()'],['../structflecs_1_1system__builder__i.html#a4dea589a99a1e97a4998332c6becfb76',1,'flecs::system_builder_i::ctx()']]],
  ['cursor_12',['cursor',['../group__cpp__addons__meta.html#ga7801bddc835d400dc71c6261f64fba2b',1,'flecs::world::cursor(flecs::entity_t tid, void *ptr)'],['../group__cpp__addons__meta.html#gaf14e2f21de0df9ac42c914b5bf942b8b',1,'flecs::world::cursor(void *ptr)']]]
];
